| fieldsdf | R Documentation |
A data frame containing the names of retrievable fields for each of the endpoints.
fieldsdf
A data frame with the following columns:
The endpoint that this field record is for
The complete name of the field, including the parent group if applicable
The field's data type
The group the field belongs to
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.