get_endpoints: Get endpoints

View source: R/get-attribute-helpers.R

get_endpointsR Documentation

Get endpoints

Description

This function reminds the user what the possible PatentsView API endpoints are.

Usage

get_endpoints()

Value

A character vector with the names of each endpoint.


patentsview documentation built on Feb. 26, 2026, 5:07 p.m.