Learn R Programming

patentsview (version 1.0.0)

fieldsdf: Fields data frame

Description

A data frame containing the names of retrievable fields for each of the endpoints.

Usage

fieldsdf

Arguments

Format

A data frame with the following columns:

endpoint

The endpoint that this field record is for

field

The complete name of the field, including the parent group if applicable

data_type

The field's data type

group

The group the field belongs to