Learn R Programming

patentsview (version 1.0.0)

get_endpoints: Get endpoints

Description

This function reminds the user what the possible PatentsView API endpoints are.

Usage

get_endpoints()

Arguments

Value

A character vector with the names of each endpoint.