get_ok_pk: Get OK primary key

View source: R/get-attribute-helpers.R

get_ok_pkR Documentation

Get OK primary key

Description

This function suggests column(s) that you could use for the pk argument in unnest_pv_data, based on the endpoint you searched. It will return a potential primary key - either a single column or a composite set of columns - for the endpoint.

Usage

get_ok_pk(endpoint)

Arguments

endpoint

The endpoint which you would like to know a potential primary key for.

Value

The column names that represent a single row for the given endpoint.

Examples

get_ok_pk(endpoint = "inventor")
get_ok_pk(endpoint = "patent/foreign_citation")


patentsview documentation built on Feb. 26, 2026, 5:07 p.m.