View source: R/get-attribute-helpers.R
| get_ok_pk | R Documentation |
This function suggests column(s) that you could use for the pk argument
in unnest_pv_data, based on the endpoint you searched.
It will return a potential primary key - either a single column or a
composite set of columns - for the endpoint.
get_ok_pk(endpoint)
endpoint |
The endpoint which you would like to know a potential primary key for. |
The column names that represent a single row for the given endpoint.
get_ok_pk(endpoint = "inventor")
get_ok_pk(endpoint = "patent/foreign_citation")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.