Learn R Programming

patentsview (version 1.0.0)

get_ok_pk: Get OK primary key

Description

This function suggests column(s) that you could use for the pk argument in unnest_pv_data, based on the endpoint you searched. It will return a potential primary key - either a single column or a composite set of columns - for the endpoint.

Usage

get_ok_pk(endpoint)

Value

The column names that represent a single row for the given endpoint.

Arguments

endpoint

The endpoint which you would like to know a potential primary key for.

Examples

Run this code
get_ok_pk(endpoint = "inventor")
get_ok_pk(endpoint = "patent/foreign_citation")

Run the code above in your browser using DataLab