This function suggests column(s) that you could use for the pk argument
in unnest_pv_data, based on the endpoint you searched.
It will return a potential primary key - either a single column or a
composite set of columns - for the endpoint.
Usage
get_ok_pk(endpoint)
Value
The column names that represent a single row for the given endpoint.
Arguments
endpoint
The endpoint which you would like to know a potential primary
key for.