| retrieve_linked_data | R Documentation |
Some of the endpoints now return HATEOAS style links to get more data. E.g., the patent endpoint may return a link such as: "https://search.patentsview.org/api/v1/inventor/fl:th_ln:jefferson-1/". Use this function to fetch details from those links.
retrieve_linked_data(url, api_key = Sys.getenv("PATENTSVIEW_API_KEY"), ...)
url |
A link that was returned by the API on a previous call. |
api_key |
API key, it defaults to Sys.getenv("PATENTSVIEW_API_KEY"). Request a key here. |
... |
Curl options passed along to httr2's |
## Not run:
retrieve_linked_data(
"https://search.patentsview.org/api/v1/cpc_group/G01S7:4811/"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.