powered by
Some of the endpoints now return HATEOAS style links to get more data. E.g., the patent endpoint may return a link such as: "https://search.patentsview.org/api/v1/inventor/fl:th_ln:jefferson-1/". Use this function to fetch details from those links.
retrieve_linked_data(url, api_key = Sys.getenv("PATENTSVIEW_API_KEY"), ...)
A link that was returned by the API on a previous call.
API key, it defaults to Sys.getenv("PATENTSVIEW_API_KEY"). Request a key here.
Curl options passed along to httr2's req_options when we do GETs or POSTs.
req_options
if (FALSE) { retrieve_linked_data( "https://search.patentsview.org/api/v1/cpc_group/G01S7:4811/" ) }
Run the code above in your browser using DataLab