| search_pv | R Documentation |
This makes an HTTP request to the PatentsView API for data matching the user's query.
search_pv(
query,
fields = NULL,
endpoint = "patent",
subent_cnts = lifecycle::deprecated(),
mtchd_subent_only = lifecycle::deprecated(),
page = lifecycle::deprecated(),
per_page = lifecycle::deprecated(),
size = 1000,
after = NULL,
all_pages = FALSE,
sort = NULL,
method = "GET",
error_browser = lifecycle::deprecated(),
exclude_withdrawn = NULL,
api_key = Sys.getenv("PATENTSVIEW_API_KEY"),
...
)
query |
The query that the API will use to filter records.
|
fields |
A character vector of the fields that you want returned to you.
A value of Note: The primary key columns for a given endpoint will be appended to your
list of fields within Note: If you specify all fields in a given group using their full qualified
names, the group name will be substituted in the HTTTP request. This helps
make HTTP requests shorter. This substitution will not happen when you specify
all of the primary-entity fields (e.g., passing
|
endpoint |
The web service resource you wish to search. Use
|
subent_cnts |
|
mtchd_subent_only |
|
page |
|
per_page |
|
size |
The number of records that should be returned per page. This
value can be as high as 1,000 (e.g., |
after |
A list of sort key values that defaults to NULL. This
exposes the API's paging parameter for users who want to implement their own
paging. It cannot be set when |
all_pages |
Do you want to download all possible pages of output? If
|
sort |
A named character vector where the name indicates the field to
sort by and the value indicates the direction of sorting (direction should
be either "asc" or "desc"). For example, |
method |
The HTTP method that you want to use to send the request. Possible values include "GET" or "POST". Use the POST method when your query is very long (say, over 2,000 characters in length). |
error_browser |
'r lifecycle::badge("deprecated" |
exclude_withdrawn |
only used by the patent endpoint, if FALSE withdrawn patents in the database can be returned by a query. The API defaults this to TRUE, not returning withdrawn patents in the database that met the query parameter. |
api_key |
API key, it defaults to Sys.getenv("PATENTSVIEW_API_KEY"). Request a key here. |
... |
Curl options passed along to httr2's |
A list with the following three elements:
A list with one element - a named data frame containing the
data returned by the server. Each row in the data frame corresponds to a
single value for the primary entity, as defined by the endpoint's primary key.
For example, if you search the assignee endpoint, then the data frame
will be on the assignee-level, where each row corresponds to a single
assignee (primary key would be assignee_id). Fields that are not on
the assignee-level would be returned in list columns.
Entity counts across all pages of output (not just the page returned to you).
Details of the HTTP request that was sent to the server.
When you set all_pages = TRUE, you will only get a sample request.
In other words, you will not be given multiple requests for the multiple
calls that were made to the server (one for each page of results).
## Not run:
search_pv(query = '{"_gt":{"patent_year":2010}}')
search_pv(
query = qry_funs$gt(patent_year = 2010),
fields = get_fields("patent", c("patents", "assignees"))
)
search_pv(
query = qry_funs$gt(patent_year = 2010),
method = "POST",
fields = "patent_id",
sort = c("patent_id" = "asc")
)
search_pv(
query = qry_funs$eq(inventor_name_last = "Crew"),
endpoint = "inventor",
all_pages = TRUE
)
search_pv(
query = qry_funs$contains(assignee_individual_name_last = "Smith"),
endpoint = "assignee"
)
search_pv(
query = qry_funs$contains(inventors.inventor_name_last = "Smith"),
endpoint = "patent",
timeout = 40
)
search_pv(
query = qry_funs$eq(patent_id = "11530080"),
fields = "application"
)
search_pv(
query = qry_funs$eq(patent_id = "9494444"), # a withdrawn patent in the pview dbs
fields = c("patent_id", "patent_date", "withdrawn"),
exclude_withdrawn = FALSE
)
search_pv(
query = qry_funs$eq(withdrawn = TRUE),
fields = c("patent_id", "patent_date", "withdrawn"),
exclude_withdrawn = FALSE
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.