View source: R/unnest-pv-data.R
| unnest_pv_data | R Documentation |
This function converts a single data frame that has subentity-level list columns in it into multiple data frames, one for each entity/subentity. The multiple data frames can be merged together using the primary key variable specified by the user (see the relational data chapter in "R for Data Science" for an in-depth introduction to joining tabular data).
unnest_pv_data(data, pk = lifecycle::deprecated())
A list with multiple data frames, one for each entity/subentity.
Each data frame will have the pk column in it, so you can link the
tables together as needed.
## Not run:
fields <- c(
"patent_id", "patent_title",
"inventors.inventor_city", "inventors.inventor_country"
)
res <- search_pv(query = '{"_gte":{"patent_year":2015}}', fields = fields)
unnest_pv_data(data = res$data)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.